/* This file was generated by syncqt. */
#ifndef QT_QTREMOTEOBJECTS_VERSION_H
#define QT_QTREMOTEOBJECTS_VERSION_H

#define QTREMOTEOBJECTS_VERSION_STR "6.11.2"

#define QTREMOTEOBJECTS_VERSION 0x0601102

#endif // QT_QTREMOTEOBJECTS_VERSION_H
